# Core package for JEDI

## PanDA documentation 

https://panda-wms.readthedocs.io/en/latest/

## JEDI installation instructions

https://panda-wms.readthedocs.io/en/latest/installation/jedi.html

## Release notes

See ChangeLog.txt

## JEDI cluster details for ATLAS

https://github.com/PanDAWMS/panda-jedi/wiki/ATLAS-production-JEDI-servers-%5BSeptember-2023%5D

